@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2020 IBM Corporation
+ * Copyright 2018-2021 Elyra Authors
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,9 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 describe('Git', () => {
-  it('opens jupyterlab', () => {
-    cy.visit('?token=test&reset');
+  beforeEach(() => {
+    cy.resetJupyterLab();
   });
 
   it('opens git extension', () => {
